@@ -1,4 +1,4 @@
-# Copyrights 2006-2014 by [Mark Overmeer].
+# Copyrights 2006-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile;
 use vars '$VERSION';
-$VERSION = '1.48';
+$VERSION = '1.49';
 
 
 use Log::Report 'xml-compile';
@@ -33,7 +33,7 @@ __PACKAGE__->addSchemaDirs($ENV{SCHEMA_DIRECTORIES});
 __PACKAGE__->addSchemaDirs(__FILE__);
 
 
-sub new($@)
+sub new(@)
 {   my $class = shift;
     my $top   = @_ % 2 ? shift : undef;
 
